@@ -5,8 +5,8 @@ use salvo_extra::serve::{Options, StaticDir};
 async fn main() {
     tracing_subscriber::fmt().init();
 
-    let router = Router::new().path("<**path>").get(StaticDir::width_options(
-        vec!["examples/static/body", "examples/static/girl"],
+    let router = Router::with_path("<**path>").get(StaticDir::width_options(
+        vec!["examples/static/boy", "examples/static/girl"],
         Options {
             dot_files: false,
             listing: true,
