@@ -1,3 +1,5 @@
+//! Salvo is a simple but powerful web server framework written in Rust.
+
 pub use salvo_core as core;
 pub use salvo_core::*;
 
@@ -5,6 +7,8 @@ pub use salvo_core::*;
     feature = "basic_auth",
     feature = "jwt_auth",
     feature = "compression",
+    feature = "cors",
+    feature = "csrf",
     feature = "proxy",
     feature = "serve",
     feature = "sse",
